@@ -4,10 +4,10 @@
 # @author       Michael McLennan <mmclennan@purdue.edu>
 # @author       Derrick Kearney <dsk@purdue.edu>
 # @author       Nicholas J. Kisseberth <nkissebe@purdue.edu>
-# @copyright    Copyright (c) 2004-2012 HUBzero Foundation, LLC.
+# @copyright    Copyright (c) 2004-2013 HUBzero Foundation, LLC.
 # @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 #
-# Copyright (c) 2004-2012 HUBzero Foundation, LLC.
+# Copyright (c) 2004-2013 HUBzero Foundation, LLC.
 #
 # This file is part of: The HUBzero(R) Platform for Scientific Collaboration
 #
@@ -49,7 +49,7 @@ namespace eval filexfer {
 proc filexfer::connect {port callback} {
     variable installdir
 
-    if {[catch {socket localhost $port} sid] == 0} {
+    if {[catch {socket "127.0.0.1" $port} sid] == 0} {
         fconfigure $sid -buffering line
         fileevent $sid readable [list server_mesg $sid]
         return $sid
@@ -61,7 +61,7 @@ proc filexfer::connect {port callback} {
     for {set tries 10} {$tries > 0} {incr tries -1} {
         after 1000  ;# wait a minute for new server to start
 
-        if {[catch {socket localhost $port} sid] == 0} {
+        if {[catch {socket "127.0.0.1" $port} sid] == 0} {
             fconfigure $sid -buffering line
             fileevent $sid readable [list server_mesg $sid]
             return $sid
